function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import React, { useEffect } from 'react';
import { connect } from "react-redux";
import _ from 'lodash';
import Checkbox from "../checkboxs/Checkbox";
import IconButton from "@material-ui/core/IconButton";
import AddIcon from '@material-ui/icons/Add';
import SearchableSelect from "../selects/SearchableSelect";
import './style.scss';
import ConditionItem from "./ConditionItem";
import Button from "@material-ui/core/Button";
var conditionalLabel = {
  en: 'Enable Conditional Logic',
  ar: 'تمكين المنطق الشرطي'
};

function ConditionalLogic(props) {
  var conditionalLogic = _.cloneDeep(props.conditionalLogic);

  var singleFields = [];
  var multiFields = [];
  var textFields = [];
  var numberFields = [];
  var fields = [];

  var extractOptionsFromPredefined = function extractOptionsFromPredefined(referenceId, options) {
    if (referenceId) {
      for (var i = 0; i < props.predefined.length; i++) {
        if (props.predefined[i].id === referenceId) {
          return props.predefined[i].options;
        }
      }
    }

    return options;
  };

  var getOptions = function getOptions() {
    var options = {};

    var allFields = _extends({}, props.conditionableFields, props.data);

    _.map(allFields, function (field, uuid) {
      if (field.type === 'select') {
        if (field.config.isMultiple) {
          multiFields.push(field.machineName);
        } else {
          singleFields.push(field.machineName);
        }

        fields.push(field);

        if (['hiring_manager'].includes(field.machineName)) {
          var _props$users;

          options[field.machineName] = (_props$users = props.users) == null ? void 0 : _props$users.map(function (user) {
            return {
              name: user.name,
              id: user.id
            };
          });
        } else options[field.machineName] = extractOptionsFromPredefined(field.config.optionReferenceId, field.config.options);
      } else if (field.type === 'radio') {
        singleFields.push(field.machineName);
        fields.push(field);
        options[field.machineName] = options[field.machineName] = extractOptionsFromPredefined(field.config.optionReferenceId, field.config.options);
      } else if (field.type === 'checkbox') {
        multiFields.push(field.machineName);
        fields.push(field);
        options[field.machineName] = options[field.machineName] = extractOptionsFromPredefined(field.config.optionReferenceId, field.config.options);
      } else if (field.type === 'text') {
        if (field.config.subType === 'number') {
          numberFields.push(field.machineName);
          fields.push(field);
        } else {
          textFields.push(field.machineName);
          fields.push(field);
        }
      }
    });

    return options;
  };

  var _handleChange = function handleChange(val, name) {
    var _extends2;

    props.handleChange(_extends({}, props.conditionalLogic, (_extends2 = {}, _extends2[name] = val, _extends2)), 'conditionalLogic');
  };

  var enableConditionalLogic = function enableConditionalLogic(val) {
    props.handleChange(val, 'isConditionalEnabled');

    if (!val) {
      props.handleChange(_extends({}, props.conditionalLogic, {
        conditions: []
      }), 'conditionalLogic');
    }
  };

  var handleConditionChange = function handleConditionChange(val, index) {
    var conditions = _.cloneDeep(props.conditionalLogic.conditions);

    conditions[index] = val;
    props.handleChange(_extends({}, props.conditionalLogic, {
      conditions: conditions
    }), 'conditionalLogic');
  };

  var addCondition = function addCondition() {
    var conditions = _.cloneDeep(props.conditionalLogic.conditions);

    conditions.push({
      field: null,
      operator: '',
      value: ''
    });
    props.handleChange(_extends({}, props.conditionalLogic, {
      conditions: conditions
    }), 'conditionalLogic');
  };

  var _deleteCondition = function deleteCondition(index) {
    var conditions = props.conditionalLogic.conditions;
    conditions.splice(index, 1);
    props.handleChange(_extends({}, props.conditionalLogic, {
      conditions: conditions
    }), 'conditionalLogic');
  };

  var renderConditions = function renderConditions() {
    var options = getOptions();

    if (conditionalLogic.conditions.length) {
      return conditionalLogic.conditions.map(function (condition, index) {
        var errors = props.errors[index] ? props.errors[index] : {};
        return /*#__PURE__*/React.createElement(ConditionItem, {
          key: index,
          errors: errors,
          index: index,
          handleChange: function handleChange(val) {
            return handleConditionChange(val, index);
          },
          deleteCondition: function deleteCondition(e) {
            return _deleteCondition(index);
          },
          fields: fields,
          condition: condition,
          multiFields: multiFields,
          singleFields: singleFields,
          textFields: textFields,
          numberFields: numberFields,
          options: options
        });
      });
    } else {
      return /*#__PURE__*/React.createElement("div", {
        className: "ahfb-width-full ahfb-py-3 ahfb-text-center"
      }, /*#__PURE__*/React.createElement("p", {
        className: "ahfb-text-muted"
      }, "Click below to add condition."));
    }
  };

  if (props.isConditionalEnabled) {
    return /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement(Checkbox, {
      checked: props.isConditionalEnabled,
      handleChange: function handleChange(val) {
        return enableConditionalLogic(val);
      },
      label: "Enable Conditional Logic"
    })), /*#__PURE__*/React.createElement("div", {
      className: "ahfb-d-flow-root"
    }, /*#__PURE__*/React.createElement("span", {
      className: "ahfb-float-left ahfb-conditional-main-dropdowns ahfb-mr-1"
    }, /*#__PURE__*/React.createElement(SearchableSelect, {
      value: props.conditionalLogic.display,
      handleChange: function handleChange(e) {
        return _handleChange(e.target.value, 'display');
      },
      options: [{
        label: 'Show',
        value: 'show'
      }, {
        label: 'Hide',
        value: 'hide'
      }],
      disableClearable: true
    })), /*#__PURE__*/React.createElement("span", {
      className: "ahfb-d-flex ahfb-float-left ahfb-mt-1"
    }, " this field if "), /*#__PURE__*/React.createElement("span", {
      className: "ahfb-float-left ahfb-conditional-main-dropdowns ahfb-mx-1"
    }, /*#__PURE__*/React.createElement(SearchableSelect, {
      value: props.conditionalLogic.logic,
      handleChange: function handleChange(e) {
        return _handleChange(e.target.value, 'logic');
      },
      options: [{
        label: 'All',
        value: 'all'
      }, {
        label: 'Any',
        value: 'any'
      }],
      disableClearable: true
    })), /*#__PURE__*/React.createElement("span", {
      className: "ahfb-d-flex ahfb-float-left ahfb-mt-1"
    }, " of the following match:")), /*#__PURE__*/React.createElement("div", {
      className: "ahfb-mt-2"
    }, renderConditions(), /*#__PURE__*/React.createElement("div", {
      className: "ahfb-clearfix"
    }, /*#__PURE__*/React.createElement(Button, {
      onClick: addCondition
    }, /*#__PURE__*/React.createElement(AddIcon, null), " ", conditionalLogic.conditions.length ? 'Add another condition' : 'Add condition'))));
  } else {
    return /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement(Checkbox, {
      checked: props.isConditionalEnabled,
      handleChange: function handleChange(val) {
        return enableConditionalLogic(val);
      },
      label: conditionalLabel[props.currentLang]
    }));
  }
}

var mapStateToProps = function mapStateToProps(state) {
  return {
    data: state.form.data,
    users: state.form.users,
    conditionableFields: state.form.conditionableFields,
    currentLang: state.form.currentLang
  };
};

var mapDispatchToProps = function mapDispatchToProps(dispatch) {
  return {};
};

export default connect(mapStateToProps, mapDispatchToProps)(ConditionalLogic);