function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import React, { useRef } from 'react';
import { InputLabel, Typography, Button, Box, LinearProgress } from "@material-ui/core";
import './style.scss';
import FormHelperText from "@material-ui/core/FormHelperText";
import axios from 'axios';
import { fileListToArray } from '../helpers';
import { makeStyles } from "@material-ui/core/styles";
import { connect } from "react-redux";
var dragAndDrop = {
  en: 'Drag and drop files here',
  ar: 'السحب والإفلات هنا'
};
var or = {
  en: 'or',
  ar: 'أو'
};
var browseFiles = {
  en: 'Browse Files',
  ar: 'تصفح ملفات'
};
var replaceFiles = {
  en: 'Replace Files',
  ar: 'استبدال الملفات'
};
var useStyles = makeStyles(function (theme) {
  return {
    highlight: {
      border: '2px dashed',
      borderColor: theme.palette.primary.main
    }
  };
});

function LinearProgressWithLabel(props) {
  return /*#__PURE__*/React.createElement(Box, {
    display: "flex",
    alignItems: "center"
  }, /*#__PURE__*/React.createElement(Box, {
    width: "100%",
    mr: 1
  }, /*#__PURE__*/React.createElement(LinearProgress, _extends({
    variant: "determinate",
    style: {
      height: 10
    }
  }, props))), /*#__PURE__*/React.createElement(Box, {
    minWidth: 35
  }, /*#__PURE__*/React.createElement(Typography, {
    variant: "body2",
    color: "textSecondary"
  }, Math.round(props.value) + "%")));
}

function FileUpload(props) {
  var fileUploader = useRef(null);

  var _React$useState = React.useState(false),
      highlight = _React$useState[0],
      setHightlight = _React$useState[1];

  var _React$useState2 = React.useState(false),
      uploading = _React$useState2[0],
      setUploading = _React$useState2[1];

  var _React$useState3 = React.useState(null),
      error = _React$useState3[0],
      setError = _React$useState3[1];

  var _React$useState4 = React.useState(0),
      progress = _React$useState4[0],
      setProgress = _React$useState4[1];

  var classes = useStyles();

  var onDragOver = function onDragOver(evt) {
    evt.preventDefault();
    setHightlight(true);
  };

  var onDragLeave = function onDragLeave() {
    setHightlight(false);
  };

  var onDrop = function onDrop(event) {
    event.preventDefault();
    setHightlight(false);

    if (props.uploadable) {
      setUploading(true);
      var files = event.dataTransfer.files;
      uploadFile(files);
    }
  };

  var onFilesAdded = function onFilesAdded(e) {
    if (props.uploadable) {
      setUploading(true);
      var files = e.target.files;
      uploadFile(files);
    }
  };

  var openBrowser = function openBrowser() {
    fileUploader.current.click();
  };

  var validateExtensions = function validateExtensions(file) {
    if (props.variant) {
      var parts = file.name.split('.');
      var extension = parts[parts.length - 1];

      if (props.variant === 'images' && !['jpg', 'jpeg', 'png', 'gif', 'JPG', 'PNG', 'GIF', 'JPEG'].includes(extension)) {
        setError('Invalid file format. Please use one of these: jpg, jpeg, png, gif');
        return false;
      } else if (props.variant === 'videos' && !['mp4', 'webm', 'ogg', 'MP4', 'WEBM', 'OGG'].includes(extension)) {
        setError('Invalid file format. Please use one of these: mp4, webm, ogg');
        return false;
      }
    }

    return true;
  };

  var uploadFile = function uploadFile(files) {
    setError(null);
    var array = fileListToArray(files);

    if (array.length > 1) {
      setError('Only one file is allowed');
    } else {
      if (validateExtensions(array[0])) {
        var config = {
          onUploadProgress: function onUploadProgress(progressEvent) {
            return setProgress(Math.round(progressEvent.loaded * 100 / progressEvent.total));
          }
        };
        var formData = new FormData();
        formData.append('file', array[0]);
        formData.append('provider', 'true');
        axios.post(props.fileUploadUrl, formData, config).then(function (res) {
          props.updateUrl(res.data.path);
          setUploading(false);
          setProgress(0);
        })["catch"](function (err) {
          if (err.response.status) {
            setError('Invalid file format');
          } else {
            setError('Unable to upload file, try again later');
          }

          setUploading(false);
          setProgress(0);
        });
      } else {
        setUploading(false);
        setProgress(0);
      }
    }
  };

  var renderImage = function renderImage() {
    if (props.url && props.url !== '') {
      return /*#__PURE__*/React.createElement("img", {
        src: props.url,
        className: "ahfb-width-full ahfb-file-upload-preview"
      });
    } else {
      return /*#__PURE__*/React.createElement("img", {
        src: "https://cdn1.iconfinder.com/data/icons/hawcons/32/698394-icon-130-cloud-upload-512.png",
        width: "100"
      });
    }
  };

  var renderVideo = function renderVideo() {
    if (props.url && props.url !== '') {
      return /*#__PURE__*/React.createElement("video", {
        className: "ahfb-width-full ahfb-file-upload-preview",
        controls: true
      }, /*#__PURE__*/React.createElement("source", {
        src: props.url
      }));
    } else {
      return /*#__PURE__*/React.createElement("img", {
        src: "https://cdn1.iconfinder.com/data/icons/hawcons/32/698394-icon-130-cloud-upload-512.png",
        width: "100"
      });
    }
  };

  var renderDropzone = function renderDropzone() {
    var className = 'ahfb-dropzone';

    if (uploading) {
      if (props.url && props.url !== '') {
        className += ' ahfb-pt-0';
      }

      return /*#__PURE__*/React.createElement("div", {
        className: className
      }, props.variant === 'images' ? renderImage() : renderVideo(), /*#__PURE__*/React.createElement("div", {
        className: "ahfb-width-full ahfb-pl-3 ahfb-pr-2 ahfb-pt-3"
      }, /*#__PURE__*/React.createElement(LinearProgressWithLabel, {
        value: progress
      })));
    } else {
      if (props.url && props.url !== '') {
        className += ' ahfb-pt-0';
      }

      if (highlight) {
        className += ' ' + classes.highlight;
      }

      return /*#__PURE__*/React.createElement("div", {
        className: className,
        onDragOver: onDragOver,
        onDragLeave: onDragLeave,
        onDrop: onDrop
      }, props.variant === 'images' ? renderImage() : renderVideo(), /*#__PURE__*/React.createElement(Typography, {
        variant: "h6",
        className: "ahfb-dropzone-label"
      }, props.placeholder && props.currentLang === 'en' ? props.placeholder : dragAndDrop[props.currentLang]), /*#__PURE__*/React.createElement(InputLabel, null, or[props.currentLang]), /*#__PURE__*/React.createElement(Button, {
        variant: "outlined",
        onClick: openBrowser
      }, props.url && props.url !== '' ? replaceFiles[props.currentLang] : browseFiles[props.currentLang]));
    }
  };

  return /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement(InputLabel, {
    required: props.required
  }, props.label), /*#__PURE__*/React.createElement("input", {
    type: "file",
    id: "file",
    multiple: !!props.isMultiple,
    ref: fileUploader,
    className: "ahfb-hidden",
    onChange: onFilesAdded
  }), renderDropzone(), /*#__PURE__*/React.createElement(FormHelperText, null, props.helperText), error ? /*#__PURE__*/React.createElement(FormHelperText, {
    error: true
  }, error) : "");
}

var mapStateToProps = function mapStateToProps(state) {
  return {
    currentLang: state.form.currentLang
  };
};

var mapDispatchToProps = function mapDispatchToProps(dispatch) {
  return {};
};

export default connect(mapStateToProps, mapDispatchToProps)(FileUpload);