"use strict";

exports.__esModule = true;
exports["default"] = ConditionItem;

var _react = _interopRequireDefault(require("react"));

var _SearchableSelect = _interopRequireDefault(require("../selects/SearchableSelect"));

var _TextInput = _interopRequireDefault(require("../inputs/TextInput"));

var _MultiSelect = _interopRequireDefault(require("../selects/MultiSelect"));

var _Typography = _interopRequireDefault(require("@material-ui/core/Typography"));

var _Divider = _interopRequireDefault(require("@material-ui/core/Divider"));

var _IconButton = _interopRequireDefault(require("@material-ui/core/IconButton"));

var _Clear = _interopRequireDefault(require("@material-ui/icons/Clear"));

var _core = require("@material-ui/core");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function ConditionItem(props) {
  var getOptions = function getOptions() {
    var options = [{
      label: 'Contains',
      value: 'contain'
    }, {
      label: 'Starts with',
      value: 'prefix'
    }, {
      label: 'Ends with',
      value: 'postfix'
    }];

    if (props.condition.field) {
      if (props.multiFields.includes(props.condition.field)) {
        options = [{
          label: 'Includes',
          value: 'includes'
        }, {
          label: 'Include Any',
          value: 'include-any'
        }, {
          label: 'Excludes',
          value: 'excludes'
        }, {
          label: 'Exclude Any',
          value: 'exclude-any'
        }];
      } else if (props.singleFields.includes(props.condition.field)) {
        options = [{
          label: 'Is',
          value: 'is'
        }, {
          label: 'Is Not',
          value: 'not'
        }];
      } else if (props.numberFields.includes(props.condition.field)) {
        options = [{
          label: 'Equals',
          value: 'equal'
        }, {
          label: 'Greater than',
          value: 'greater'
        }, {
          label: 'Less than',
          value: 'less'
        }];
      }
    }

    return options;
  };

  var getType = function getType() {
    var type = 'text';

    if (props.condition.field) {
      if (props.multiFields.includes(props.condition.field)) {
        type = 'multiple';
      } else if (props.singleFields.includes(props.condition.field)) {
        type = 'single';
      } else if (props.numberFields.includes(props.condition.field)) {
        type = 'number';
      }
    }

    return type;
  };

  var _handleChange = function handleChange(val, name) {
    var _extends2;

    var condition = _extends({}, props.condition, (_extends2 = {
      value: name === 'field' ? '' : props.condition.value,
      // reset the state of field if changed
      operator: name === 'field' ? '' : props.condition.operator
    }, _extends2[name] = val, _extends2));

    props.handleChange(condition);
  };

  var renderOptions = function renderOptions() {
    var type = getType();

    if (type === 'number') {
      return /*#__PURE__*/_react["default"].createElement(_TextInput["default"], {
        placeholder: "Value",
        type: "number",
        value: props.condition.value,
        handleChange: function handleChange(e) {
          return _handleChange(e.target.value, 'value');
        },
        error: props.errors.value
      });
    } else if (type === 'single') {
      return /*#__PURE__*/_react["default"].createElement(_SearchableSelect["default"], {
        disableClearable: true,
        placeholder: "Value",
        options: props.options[props.condition.field],
        value: props.condition.value,
        handleChange: function handleChange(e) {
          return _handleChange(e.target.value, 'value');
        },
        error: props.errors.value,
        labelProp: "name",
        valueProp: "id"
      });
    } else if (type === 'multiple') {
      return /*#__PURE__*/_react["default"].createElement(_MultiSelect["default"], {
        placeholder: "Value",
        options: props.options[props.condition.field],
        value: props.condition.value,
        handleChange: function handleChange(e) {
          return _handleChange(e.target.value, 'value');
        },
        error: props.errors.value,
        labelProp: "name",
        valueProp: "id"
      });
    } else {
      return /*#__PURE__*/_react["default"].createElement(_TextInput["default"], {
        placeholder: "Value",
        value: props.condition.value,
        handleChange: function handleChange(e) {
          return _handleChange(e.target.value, 'value');
        },
        error: props.errors.value
      });
    }
  };

  return /*#__PURE__*/_react["default"].createElement(_core.Grid, {
    container: true,
    className: "ahfb-mx-0 ahfb-pt-2 ahfb-pb-3 ahfb-px-2 ahfb-conditions-item-main ahfb-mb-3"
  }, /*#__PURE__*/_react["default"].createElement(_core.Grid, {
    item: true,
    xs: 10,
    className: "ahfb-pl-0"
  }, /*#__PURE__*/_react["default"].createElement(_Typography["default"], {
    variant: "button"
  }, "Condition #", props.index + 1)), /*#__PURE__*/_react["default"].createElement(_core.Grid, {
    item: true,
    xs: 2,
    className: "ahfb-text-right ahfb-pr-0"
  }, /*#__PURE__*/_react["default"].createElement(_IconButton["default"], {
    size: "small",
    onClick: props.deleteCondition
  }, /*#__PURE__*/_react["default"].createElement(_Clear["default"], {
    fontSize: "small",
    className: "ahfb-pull-right",
    color: "action"
  }))), /*#__PURE__*/_react["default"].createElement("hr", {
    className: "ahfb-condition-divider ahfb-mt-0 ahfb-mb-2"
  }), /*#__PURE__*/_react["default"].createElement(_core.Grid, {
    item: true,
    xs: 12,
    className: "ahfb-px-1 ahfb-mb-2"
  }, /*#__PURE__*/_react["default"].createElement(_SearchableSelect["default"], {
    disableClearable: true,
    placeholder: "Field",
    options: props.fields,
    labelProp: "name",
    valueProp: "machineName",
    value: props.condition.field,
    handleChange: function handleChange(e) {
      return _handleChange(e.target.value, 'field');
    },
    error: props.errors.field
  })), /*#__PURE__*/_react["default"].createElement(_core.Grid, {
    item: true,
    xs: 6,
    className: "ahfb-pr-1"
  }, /*#__PURE__*/_react["default"].createElement(_SearchableSelect["default"], {
    disableClearable: true,
    placeholder: "Operator",
    options: getOptions(),
    value: props.condition.operator,
    handleChange: function handleChange(e) {
      return _handleChange(e.target.value, 'operator');
    },
    error: props.errors.operator
  })), /*#__PURE__*/_react["default"].createElement(_core.Grid, {
    item: true,
    xs: 6,
    className: "ahfb-pl-1"
  }, renderOptions()));
}

module.exports = exports.default;