"use strict";

exports.__esModule = true;
exports["default"] = void 0;

var _react = _interopRequireWildcard(require("react"));

var _core = require("@material-ui/core");

require("./style.scss");

var _FormHelperText = _interopRequireDefault(require("@material-ui/core/FormHelperText"));

var _axios = _interopRequireDefault(require("axios"));

var _helpers = require("../helpers");

var _styles = require("@material-ui/core/styles");

var _reactRedux = require("react-redux");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { "default": obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj["default"] = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

var dragAndDrop = {
  en: 'Drag and drop files here',
  ar: 'السحب والإفلات هنا'
};
var or = {
  en: 'or',
  ar: 'أو'
};
var browseFiles = {
  en: 'Browse Files',
  ar: 'تصفح ملفات'
};
var replaceFiles = {
  en: 'Replace Files',
  ar: 'استبدال الملفات'
};
var useStyles = (0, _styles.makeStyles)(function (theme) {
  return {
    highlight: {
      border: '2px dashed',
      borderColor: theme.palette.primary.main
    }
  };
});

function LinearProgressWithLabel(props) {
  return /*#__PURE__*/_react["default"].createElement(_core.Box, {
    display: "flex",
    alignItems: "center"
  }, /*#__PURE__*/_react["default"].createElement(_core.Box, {
    width: "100%",
    mr: 1
  }, /*#__PURE__*/_react["default"].createElement(_core.LinearProgress, _extends({
    variant: "determinate",
    style: {
      height: 10
    }
  }, props))), /*#__PURE__*/_react["default"].createElement(_core.Box, {
    minWidth: 35
  }, /*#__PURE__*/_react["default"].createElement(_core.Typography, {
    variant: "body2",
    color: "textSecondary"
  }, Math.round(props.value) + "%")));
}

function FileUpload(props) {
  var fileUploader = (0, _react.useRef)(null);

  var _React$useState = _react["default"].useState(false),
      highlight = _React$useState[0],
      setHightlight = _React$useState[1];

  var _React$useState2 = _react["default"].useState(false),
      uploading = _React$useState2[0],
      setUploading = _React$useState2[1];

  var _React$useState3 = _react["default"].useState(null),
      error = _React$useState3[0],
      setError = _React$useState3[1];

  var _React$useState4 = _react["default"].useState(0),
      progress = _React$useState4[0],
      setProgress = _React$useState4[1];

  var classes = useStyles();

  var onDragOver = function onDragOver(evt) {
    evt.preventDefault();
    setHightlight(true);
  };

  var onDragLeave = function onDragLeave() {
    setHightlight(false);
  };

  var onDrop = function onDrop(event) {
    event.preventDefault();
    setHightlight(false);

    if (props.uploadable) {
      setUploading(true);
      var files = event.dataTransfer.files;
      uploadFile(files);
    }
  };

  var onFilesAdded = function onFilesAdded(e) {
    if (props.uploadable) {
      setUploading(true);
      var files = e.target.files;
      uploadFile(files);
    }
  };

  var openBrowser = function openBrowser() {
    fileUploader.current.click();
  };

  var validateExtensions = function validateExtensions(file) {
    if (props.variant) {
      var parts = file.name.split('.');
      var extension = parts[parts.length - 1];

      if (props.variant === 'images' && !['jpg', 'jpeg', 'png', 'gif', 'JPG', 'PNG', 'GIF', 'JPEG'].includes(extension)) {
        setError('Invalid file format. Please use one of these: jpg, jpeg, png, gif');
        return false;
      } else if (props.variant === 'videos' && !['mp4', 'webm', 'ogg', 'MP4', 'WEBM', 'OGG'].includes(extension)) {
        setError('Invalid file format. Please use one of these: mp4, webm, ogg');
        return false;
      }
    }

    return true;
  };

  var uploadFile = function uploadFile(files) {
    setError(null);
    var array = (0, _helpers.fileListToArray)(files);

    if (array.length > 1) {
      setError('Only one file is allowed');
    } else {
      if (validateExtensions(array[0])) {
        var config = {
          onUploadProgress: function onUploadProgress(progressEvent) {
            return setProgress(Math.round(progressEvent.loaded * 100 / progressEvent.total));
          }
        };
        var formData = new FormData();
        formData.append('file', array[0]);
        formData.append('provider', 'true');

        _axios["default"].post(props.fileUploadUrl, formData, config).then(function (res) {
          props.updateUrl(res.data.path);
          setUploading(false);
          setProgress(0);
        })["catch"](function (err) {
          if (err.response.status) {
            setError('Invalid file format');
          } else {
            setError('Unable to upload file, try again later');
          }

          setUploading(false);
          setProgress(0);
        });
      } else {
        setUploading(false);
        setProgress(0);
      }
    }
  };

  var renderImage = function renderImage() {
    if (props.url && props.url !== '') {
      return /*#__PURE__*/_react["default"].createElement("img", {
        src: props.url,
        className: "ahfb-width-full ahfb-file-upload-preview"
      });
    } else {
      return /*#__PURE__*/_react["default"].createElement("img", {
        src: "https://cdn1.iconfinder.com/data/icons/hawcons/32/698394-icon-130-cloud-upload-512.png",
        width: "100"
      });
    }
  };

  var renderVideo = function renderVideo() {
    if (props.url && props.url !== '') {
      return /*#__PURE__*/_react["default"].createElement("video", {
        className: "ahfb-width-full ahfb-file-upload-preview",
        controls: true
      }, /*#__PURE__*/_react["default"].createElement("source", {
        src: props.url
      }));
    } else {
      return /*#__PURE__*/_react["default"].createElement("img", {
        src: "https://cdn1.iconfinder.com/data/icons/hawcons/32/698394-icon-130-cloud-upload-512.png",
        width: "100"
      });
    }
  };

  var renderDropzone = function renderDropzone() {
    var className = 'ahfb-dropzone';

    if (uploading) {
      if (props.url && props.url !== '') {
        className += ' ahfb-pt-0';
      }

      return /*#__PURE__*/_react["default"].createElement("div", {
        className: className
      }, props.variant === 'images' ? renderImage() : renderVideo(), /*#__PURE__*/_react["default"].createElement("div", {
        className: "ahfb-width-full ahfb-pl-3 ahfb-pr-2 ahfb-pt-3"
      }, /*#__PURE__*/_react["default"].createElement(LinearProgressWithLabel, {
        value: progress
      })));
    } else {
      if (props.url && props.url !== '') {
        className += ' ahfb-pt-0';
      }

      if (highlight) {
        className += ' ' + classes.highlight;
      }

      return /*#__PURE__*/_react["default"].createElement("div", {
        className: className,
        onDragOver: onDragOver,
        onDragLeave: onDragLeave,
        onDrop: onDrop
      }, props.variant === 'images' ? renderImage() : renderVideo(), /*#__PURE__*/_react["default"].createElement(_core.Typography, {
        variant: "h6",
        className: "ahfb-dropzone-label"
      }, props.placeholder && props.currentLang === 'en' ? props.placeholder : dragAndDrop[props.currentLang]), /*#__PURE__*/_react["default"].createElement(_core.InputLabel, null, or[props.currentLang]), /*#__PURE__*/_react["default"].createElement(_core.Button, {
        variant: "outlined",
        onClick: openBrowser
      }, props.url && props.url !== '' ? replaceFiles[props.currentLang] : browseFiles[props.currentLang]));
    }
  };

  return /*#__PURE__*/_react["default"].createElement("div", null, /*#__PURE__*/_react["default"].createElement(_core.InputLabel, {
    required: props.required
  }, props.label), /*#__PURE__*/_react["default"].createElement("input", {
    type: "file",
    id: "file",
    multiple: !!props.isMultiple,
    ref: fileUploader,
    className: "ahfb-hidden",
    onChange: onFilesAdded
  }), renderDropzone(), /*#__PURE__*/_react["default"].createElement(_FormHelperText["default"], null, props.helperText), error ? /*#__PURE__*/_react["default"].createElement(_FormHelperText["default"], {
    error: true
  }, error) : "");
}

var mapStateToProps = function mapStateToProps(state) {
  return {
    currentLang: state.form.currentLang
  };
};

var mapDispatchToProps = function mapDispatchToProps(dispatch) {
  return {};
};

var _default = (0, _reactRedux.connect)(mapStateToProps, mapDispatchToProps)(FileUpload);

exports["default"] = _default;
module.exports = exports.default;